<?php

namespace Drupal\light_saml_idp\Entity;

use Drupal\Core\Entity\EntityRepository;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Plugin\Context\ContextRepositoryInterface;

/**
 * Service provider repository.
 */
class ServiceProviderRepository extends EntityRepository {

  /**
   * Entity storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $entityStorage;

  /**
   * ServiceProviderRepository constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity type manager service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   Language manager service.
   * @param \Drupal\Core\Plugin\Context\ContextRepositoryInterface $context_repository
   *   Context repository service.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, LanguageManagerInterface $language_manager, ContextRepositoryInterface $context_repository) {
    parent::__construct($entity_type_manager, $language_manager, $context_repository);
    $this->entityStorage = ($this->entityTypeManager->getStorage('serviceProvider'));
  }

  /**
   * Load entity by its id.
   *
   * @param string $entityId
   *   Id of entity to load.
   *
   * @return \Drupal\light_saml_idp\Entity\ServiceProviderInterface|null
   *   Service provider entity.
   */
  public function loadEntityByEntityId(string $entityId): ?ServiceProviderInterface {
    $entities = $this->entityStorage->loadByProperties(['entityId' => $entityId]);
    return ($entities) ? reset($entities) : NULL;
  }

}
